### Name: lcr
### Title: Linear categorical regression
### Aliases: print.lcr extractAIC.lcr deviance.lcr fitted.lcr names.lcr
### Keywords: models

### ** Examples

library(ordinal)

#
# Binary example:
#
data(cardiac)

resp <- cardiac[,1:4]
freq <- cardiac[,11]

age <- cardiac[,5]
sex <- cardiac[,6]
pmi <- cardiac[,7]
dia <- cardiac[,8]
ren <- cardiac[,9]
cop <- cardiac[,10]

rm(cardiac)

y <- restovec(resp,times=T,weights=freq,type="ordinal")

tcc <- tcctomat(age,name="age")
tcc <- tcctomat(sex,name="sex",oldccov=tcc)
tcc <- tcctomat(pmi,name="pmi",oldccov=tcc)
tcc <- tcctomat(dia,name="dia",oldccov=tcc)
tcc <- tcctomat(ren,name="ren",oldccov=tcc)
tcc <- tcctomat(cop,name="cop",oldccov=tcc)

tvc <- tvctomat(matrix(times(y)^2,ncol=4,byrow=T),name="times2")

w <- rmna(y,ccov=tcc,tvcov=tvc)

rm(resp,freq,age,sex,pmi,dia,ren,cop,y,tcc,tvc)

lcr(w)
lcr(w,mu=~times)
lcr(w,mu=~age+sex+times+times2)
lcr(w,mu=~age+sex+pmi+dia+ren+cop+pmi:dia+pmi:cop+dia:cop+times)
lcr(w,mu=~age+sex+pmi+dia+ren+cop+pmi:dia+pmi:cop+dia:cop+times+times2)

rm(w)

#
# Multinomial example:
#
data(criminal)

resp <- criminal[,2]-1
freq <- criminal[,5]

race <- criminal[,3]-1
county <- criminal[,4]-1
trial <- as.factor(criminal[,1])

rm(criminal)

y <- restovec(resp,times=F,weights=freq,type="ordinal")

tcc <- tcctomat(race,name="race")
tcc <- tcctomat(county,name="county",oldccov=tcc)
tcc <- tcctomat(trial,name="trial",oldccov=tcc)

w <- rmna(y,ccov=tcc)

rm(resp,freq,race,county,trial,y,tcc)

lcr(w)
lcr(w,mu=~race)
lcr(w,mu=~race+county)
lcr(w,mu=~race+county+trial)

#
# Simplified multinomial example:
#
lcr(w,dist="simpl")
lcr(w,dist="simpl",mu=~race)
lcr(w,dist="simpl",mu=~race+county)
lcr(w,dist="simpl",mu=~race+county+trial)

rm(w)

#
# Continuation ratio (upwards) example:
#
data(tmi)

resp <- tmi[,1:4]-1
freq <- tmi[,6]

cov <- matrix(tmi[,5],ncol=1,dimnames=list(NULL,"distance"))

rm(tmi)

y <- restovec(resp,times=T,weights=freq,type="ordinal")

tcc <- tcctomat(cov,name="distance")

w <- rmna(y,ccov=tcc)

rm(resp,freq,cov,y,tcc)

lcr(w,distribution="cont")
lcr(w,mu=~distance,distribution="cont")
lcr(w,mu=~distance+times,distribution="cont")

#
# Continuation ratio (downwards) example:
#
lcr(w,distribution="cont",direc="down")
lcr(w,distribution="cont",direc="down",mu=~distance)
lcr(w,distribution="cont",direc="down",mu=~distance+times)

#
# Proportional odds example:
#
lcr(w,distribution="prop")
lcr(w,distribution="prop",mu=~distance)
lcr(w,distribution="prop",mu=~distance+times)

#
# Adjacent categories example:
#
lcr(w,distribution="adj")
lcr(w,distribution="adj",mu=~distance)
lcr(w,distribution="adj",mu=~distance+times)

#
# Example using links:
#
lcr(w,distribution="prop",mu=~distance)
lcr(w,distribution="prop",mu=~distance,link="probit",pcoef=c(-1.3634,0.589,0.1709))
lcr(w,distribution="prop",mu=~distance,link="log-normal",transform="log",pcoef=c(-1.3634,0.589,0.1709))
lcr(w,distribution="prop",mu=~distance,link="Cauchy",pcoef=c(-2.9979,0.6297,0.5164))
lcr(w,distribution="prop",mu=~distance,link="Laplace",pcoef=c(-1.6946,0.5448,0.2531))
lcr(w,distribution="prop",mu=~distance,link="gen logistic",pcoef=c(-1.691,3.2053,0.4578),plink=2)
lcr(w,distribution="prop",mu=~distance,link="gen extreme value",transform="logit",pcoef=c(-2.9815,2.3526,0.6966),plink=1)
lcr(w,distribution="prop",mu=~distance,link="gen extreme value",transform="logit",pcoef=c(-5.8473,-1.6886,0.3214),plink=1/2)
lcr(w,distribution="prop",mu=~distance,link="power exponential",pcoef=c(-3.3892,1.0895,0.5061),plink=1/2)
lcr(w,distribution="prop",mu=~distance,link="stable",pcoef=c(-1.9281,0.8331,0.2417),plink=c(0,2))
lcr(w,distribution="prop",mu=~distance,link="nc F",transform="log",pcoef=c(-2.8999,2.2461,0.5254),plink=c(1,1,1))
lcr(w,distribution="prop",mu=~distance,link="nc F",transform="log",pcoef=c(-3.318,2.091,0.382),plink=c(1/2,3,2))

rm(w)



